/*
 * Copyright 2014 Dmytro Titov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.github.autsia.crowly.controllers.rest;

import io.github.autsia.crowly.model.CrowlyUser;
import io.github.autsia.crowly.repositories.UserRepository;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Created by Dmytro on 04.01.14 at 21:02
 * Project: crowly
 */
@RestController("restUsersController")
@RequestMapping("/rest/users")
public class UsersController {

    private static final Logger logger = Logger.getLogger(UsersController.class);

    private UserRepository userRepository;

    // Do not change parameters order - it's important for aspect pointcut
    @RequestMapping(value = "/pages", method = RequestMethod.GET)
    public int pages(@RequestParam(defaultValue = "0") int page,
                     @RequestParam int size,
                     HttpServletResponse response) {
        return userRepository.findAll(new PageRequest(page, size)).getTotalPages();
    }

    // Do not change parameters order - it's important for aspect pointcut
    @RequestMapping(value = "/users", method = RequestMethod.GET)
    public List<CrowlyUser> users(@RequestParam int page,
                                  @RequestParam int size,
                                  @RequestParam(defaultValue = "true") boolean direction,
                                  @RequestParam(defaultValue = "email") String sortProperty,
                                  HttpServletResponse response) {
        return userRepository.findAll(new PageRequest(page, size,
                new Sort(direction ? Sort.Direction.ASC : Sort.Direction.DESC, sortProperty))).getContent();
    }

    @RequestMapping(value = "/details", method = RequestMethod.GET)
    public CrowlyUser details(@RequestParam(required = true) String userId,
                              HttpServletResponse response) {
        return userRepository.findById(userId);
    }

    @Autowired
    public void setUserRepository(UserRepository userRepository) {
        this.userRepository = userRepository;
    }

}
