/*
 * Copyright 2014 Dmytro Titov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.github.autsia.crowly.services.scheduling.jobs.impl;

import io.github.autsia.crowly.model.Campaign;
import io.github.autsia.crowly.model.Mention;
import io.github.autsia.crowly.repositories.MentionRepository;
import io.github.autsia.crowly.services.scheduling.impl.CampaignsManagerImpl;
import io.github.autsia.crowly.services.scheduling.jobs.CrawlingJob;
import io.github.autsia.crowly.services.social.SocialEndpoint;
import io.github.autsia.crowly.services.social.SocialEndpointsFacade;
import org.apache.log4j.Logger;
import org.quartz.JobExecutionContext;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * Created by Dmytro on 4/25/2014 at 22:43
 * Project: crowly
 */
public class CrawlingJobImpl implements CrawlingJob {

    private static final Logger logger = Logger.getLogger(CrawlingJobImpl.class);

    protected Campaign campaign;
    protected SocialEndpointsFacade socialEndpointsFacade;
    protected MentionRepository mentionRepository;

    @Override
    public void execute(JobExecutionContext jobExecutionContext) {
        try {
            campaign = (Campaign) jobExecutionContext.getJobDetail().getJobDataMap().get(CampaignsManagerImpl.CAMPAIGN_KEY);
            socialEndpointsFacade = (SocialEndpointsFacade) jobExecutionContext.getJobDetail().getJobDataMap().get(CampaignsManagerImpl.SOCIAL_ENDPOINTS_FACADE_KEY);
            mentionRepository = (MentionRepository) jobExecutionContext.getJobDetail().getJobDataMap().get(CampaignsManagerImpl.MENTION_REPOSITORY_KEY);
            perform();
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
        }
    }

    @Override
    public void perform() {
        Set<String> socialEndpointsNames = campaign.getSocialEndpoints();
        List<Mention> mentions = new ArrayList<>();
        for (String socialEndpointName : socialEndpointsNames) {
            SocialEndpoint socialEndpoint = socialEndpointsFacade.getByName(socialEndpointName);
            mentions.addAll(socialEndpoint.gatherMentions(campaign));
        }
        mentionRepository.save(mentions);
    }

}
