/*
 * Copyright 2014 Dmytro Titov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License act
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var crowlyApp = angular.module('crowly', []);

crowlyApp.controller('UsersController', function ($scope, $http) {

    $scope.documents = [];

    $scope.init = function () {
        jQuery('.inline-filter').hide();
        $scope.page = 0;
        $scope.direction = true;
        $scope.sortProperty = 'email';
        $scope.setSize(10);
        $scope.update();
    };

    $scope.range = function (start, end) {
        var ret = [];
        if (!end) {
            end = start;
            start = 0;
        }
        for (var i = start; i < end; i++) {
            ret.push(i);
        }
        return ret;
    };

    $scope.prevPage = function () {
        if ($scope.page > 0) {
            $scope.page--;
        }
        $scope.update();
    };

    $scope.nextPage = function () {
        if ($scope.page < $scope.pages - 1) {
            $scope.page++;
        }
        $scope.update();
    };

    $scope.setPage = function () {
        $scope.page = this.n;
        $scope.update();
    };

    $scope.showUserCreateModal = function () {
        delete $scope.user;
        var modal = jQuery('#userCreateModal');
        modal.find('input').val('');
        $scope.userCreateForm.$setPristine();
        modal.modal();
    };

    $scope.createUser = function (originalUser) {
        jQuery('#userCreateFormSpinner').attr('style', 'display: inline !important');
        var user = jQuery.extend(true, {}, originalUser);
        delete user.confirm;
        user.password = CryptoJS.SHA3(user.password).toString(CryptoJS.enc.Base64);
        $http({method: 'POST', url: '/rest/authentication/register', data: user}).
            success(function (data, status, headers, config) {
                $scope.update();
                jQuery('#userCreateFormSpinner').attr('style', 'display: none !important');
                jQuery('#userCreateModal').modal('hide');
            }).
            error(function (data, status, headers, config) {
                jQuery('#userCreateFormSpinner').attr('style', 'display: none !important');
                jQuery('#userCreateModal').effect('shake', {distance: 10});
            });
    };

    $scope.update = function () {
        $http({
            method: 'GET',
            url: '/rest/users/users/',
            params: {page: $scope.page, size: $scope.size, direction: $scope.direction, sortProperty: $scope.sortProperty}
        }).success(function (data, status) {
            $scope.users = data;
        });
    };

    $scope.setSize = function (size) {
        $scope.size = size;
        $http({
            method: 'GET',
            url: '/rest/users/pages/',
            params: {size: $scope.size}
        }).success(function (data, status) {
            $scope.pages = data;
        });
        $scope.update();
    };

    $scope.sortBy = function (sortProperty) {
        if ($scope.sortProperty == sortProperty) {
            $scope.direction = !$scope.direction;
        }

        $scope.sortProperty = sortProperty;

        jQuery('.sort').removeClass().addClass('fa fa-sort sort');

        var faSort = jQuery('th.' + sortProperty + ' i')[0];
        if ($scope.direction) {
            jQuery(faSort).removeClass().addClass('fa fa-sort-up sort');
        } else {
            jQuery(faSort).removeClass().addClass('fa fa-sort-down sort');
        }

        $scope.update();
    };

    $scope.searchBy = function (attribute) {
        var input = jQuery('th.' + attribute + ' input');
        input.animate({width: 'toggle'});
    };

    $scope.details = function ($event) {
        $http({
            method: 'GET',
            url: '/rest/users/details/',
            params: {userId: $event.target.id}
        }).success(function (data, status) {
            $scope.details = data;
            jQuery('#userDetailsModal').modal();
        });
    };
});

crowlyApp.controller('CampaignsController', function ($scope, $http, $sce) {
    $scope.init = function () {
        $scope.update();
    };

    $scope.socialIconsMap = {
        'Twitter': '<i class="fa fa-twitter"></i>',
        'Facebook': '<i class="fa fa-facebook"></i>'
    };

    $scope.update = function () {
        $http({
            method: 'GET',
            url: '/rest/campaigns/all/'
        }).success(function (data, status) {
            $scope.campaigns = data;
            for (var i = 0; i < $scope.campaigns.length; i++) {
                $scope.campaigns[i].socialEndpointsIcons = [];
                for (var j = 0; j < $scope.campaigns[i].socialEndpoints.length; j++) {
                    $scope.campaigns[i].socialEndpointsIcons.push($sce.trustAsHtml($scope.socialIconsMap[$scope.campaigns[i].socialEndpoints[j]]));
                }
            }
        });
    };
});

crowlyApp.controller('MentionsController', function ($scope, $http) {
    $scope.init = function (campaignId) {
        $scope.update(campaignId);
    };

    $scope.update = function (campaignId) {
        $http({
            method: 'GET',
            url: '/rest/mentions/getByCampaign/',
            params: {campaignId: campaignId}
        }).success(function (data, status) {
            $scope.mentions = data;
        });
    };
});

crowlyApp.directive('confirm', function () {
    return {
        require: 'ngModel',
        link: function (scope, element, attrs, ngModel) {
            ngModel.$parsers.unshift(function (value) {
                var password = jQuery('#' + attrs.confirm).val();
                var valid = password == value;
                ngModel.$setValidity('confirm', valid);
                return valid ? value : undefined;
            });
        }
    };
});


crowlyApp.directive('addSwitchers', function ($q, $http) {
    return function (scope, element, attrs) {
        if (scope.campaign.status) {
            jQuery(element).find('.campaign-status').attr('checked', true);
        }
        if (scope.$last) {
            jQuery('.campaign-status').bootstrapSwitch({
                size: 'small',
                onColor: 'success',
                offColor: 'danger',
                onSwitchChange: function (event, state) {
                    $http({
                        method: 'GET',
                        url: '/rest/campaigns/changeStatus/',
                        params: {campaignId: scope.campaign.id, status: state}
                    }).error(function (data, status, headers, config) {
                        jQuery(this).setState(false);
                    });
                }
            });
        }
    };
});