/*
 * Copyright 2014 Dmytro Titov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.github.autsia.crowly.tests;

import io.github.autsia.crowly.config.TestConfig;
import io.github.autsia.crowly.services.geolocation.GeoLocationService;
import io.github.autsia.crowly.services.geolocation.impl.GeoLocationServiceImpl;
import org.apache.commons.lang3.tuple.ImmutableTriple;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.social.twitter.api.GeoCode;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.web.WebAppConfiguration;

@RunWith(SpringJUnit4ClassRunner.class)
@WebAppConfiguration
@ContextConfiguration(classes = TestConfig.class)
@ActiveProfiles("test")
public class GeoLocationServiceTests {

    protected GeoLocationService geoLocationService;

    @Test
    public void testConvertCoordinatesToGeoCode() throws Exception {
        GeoCode model = new GeoCode(1d, 2d, 3);
        GeoCode geoCode = geoLocationService.convertCoordinatesToGeoCode(new ImmutableTriple<>(1d, 2d, 3d));
        Assert.assertEquals(model.toString(), geoCode.toString());
    }

    @Test
    public void testCalculateDistance() throws Exception {
        GeoLocationServiceImpl geoLocationServiceImpl = (GeoLocationServiceImpl) geoLocationService;
        double model = 418.34d;
        double distance = geoLocationServiceImpl.calculateDistance(50.11222d, 8.68194d, 52.52222d, 13.29750d);
        Assert.assertEquals(model, distance, 0.1d);
    }

    @Autowired
    public void setGeoLocationService(GeoLocationService geoLocationService) {
        this.geoLocationService = geoLocationService;
    }

}