/*
 * Copyright 2014 Dmytro Titov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.github.autsia.crowly.tests;

import io.github.autsia.crowly.config.TestConfig;
import io.github.autsia.crowly.model.CrowlyUser;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.web.WebAppConfiguration;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.web.context.WebApplicationContext;

import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.view;
import static org.springframework.test.web.servlet.setup.MockMvcBuilders.webAppContextSetup;

/**
 * Created by Dmytro on 08.12.13 at 0:10
 * Project: crowly
 */
@RunWith(SpringJUnit4ClassRunner.class)
@WebAppConfiguration
@ContextConfiguration(classes = TestConfig.class)
@ActiveProfiles("test")
public class IntegrationTests {

    @SuppressWarnings("SpringJavaAutowiringInspection")
    @Autowired
    protected WebApplicationContext webApplicationContext;

    private MockMvc mockMvc;

    @Autowired
    private IntegrationTestingUtils integrationTestUtils;

    @Before
    public void setup() {
        this.mockMvc = webAppContextSetup(this.webApplicationContext).build();
    }

    /**
     * Web tests.
     */

    @Test
    public void index() throws Exception {
        mockMvc.perform(get("/"))
                .andExpect(status().isOk())
                .andExpect(view().name("index"));
    }

    @Test
    public void home() throws Exception {
        mockMvc.perform(get("/dashboard/home"))
                .andExpect(status().isOk())
                .andExpect(view().name("home"));
    }

    @Test
    public void users() throws Exception {
        mockMvc.perform(get("/dashboard/users"))
                .andExpect(status().isOk())
                .andExpect(view().name("users"));
    }

    /**
     * REST tests.
     */

    @Test
    public void unauthorized() throws Exception {
        CrowlyUser user = new CrowlyUser();
        user.setEmail("email");
        user.setPassword("password");
        mockMvc.perform(post("/rest/authentication/login").
                contentType(integrationTestUtils.getContentType()).
                content(integrationTestUtils.convertObjectToJsonBytes(user)))
                .andExpect(status().isUnauthorized());
    }

    @Test
    public void unsupportedMediaType() throws Exception {
        mockMvc.perform(post("/rest/authentication/login", "email", "password"))
                .andExpect(status().isUnsupportedMediaType());
    }

}
