/*
 * Copyright 2014 Dmytro Titov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.github.autsia.crowly.tests;

import io.github.autsia.crowly.config.TestConfig;
import io.github.autsia.crowly.controllers.rest.UsersController;
import io.github.autsia.crowly.model.CrowlyUser;
import io.github.autsia.crowly.repositories.UserRepository;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.web.WebAppConfiguration;

import java.util.ArrayList;
import java.util.List;

import static org.hamcrest.core.Is.is;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

/**
 * Created by Dmytro on 29.01.14 at 9:00
 * Project: crowly
 */
@RunWith(SpringJUnit4ClassRunner.class)
@WebAppConfiguration
@ContextConfiguration(classes = TestConfig.class)
@ActiveProfiles("test")
public class UserControllerTests {

    @Autowired
    private UsersController usersController;

    private UserRepository userRepositoryMock;

    private Page pageMock;

    private List<CrowlyUser> testUsersCollection;

    @Before
    public void setup() {
        userRepositoryMock = mock(UserRepository.class);
        pageMock = mock(Page.class);
        usersController.setUserRepository(userRepositoryMock);

        testUsersCollection = new ArrayList<>();
        for (int i = 0; i < 15; i++) {
            testUsersCollection.add(new CrowlyUser());
        }
    }

    @Test
    public void checkPageSizeForPages() {
        when(pageMock.getTotalPages()).thenReturn(2);
        when(userRepositoryMock.findAll(new PageRequest(0, 10))).thenReturn(pageMock);
        assertThat(usersController.pages(10, 15, null), is(2));
    }

    @Test
    public void checkPageSizeForUsers() {
        when(pageMock.getContent()).thenReturn(testUsersCollection.subList(0, 9));
        when(userRepositoryMock.findAll(new PageRequest(0, 10, new Sort(Sort.Direction.ASC, "email")))).thenReturn(pageMock);
        assertThat(usersController.users(10, 15, true, "email", null), is(testUsersCollection.subList(0, 9)));
    }

}
